@@ -13,6 +13,8 @@ import subprocess
 import os.path
 import time
 import atexit
+import signal
+
 
 class mk(object):
     """Class to manage cast process"""
@@ -32,8 +34,8 @@ class mk(object):
         self.control = mkchromecast.__init__.control
 
         self.cc = casting()
-        checkmktmp()
-        writePidFile()
+        mkchromecast.__init__.checkmktmp()
+        mkchromecast.__init__.writePidFile()
 
         """
         Initializing backend array
@@ -46,22 +48,23 @@ class mk(object):
           ]
 
         self.check_connection()
-        if self.tray == False and self.videoarg == False:
+        if self.tray is False and self.videoarg is False:
             if self.platform == 'Linux':
                 self.audio_linux()
             else:
                 self.audio_macOS()
-        elif self.tray == False and self.videoarg == True:
+        elif self.tray is False and self.videoarg is True:
             self.cast_video()
         else:
             self.start_tray()
 
     def audio_linux(self):
         """This method manages all related to casting audio in Linux"""
-        if self.youtubeurl == None and self.source_url == None:
-            if adevice == None:
+        if self.youtubeurl is None and self.source_url is None:
+            if self.adevice is None:
                 print('Creating Pulseaudio Sink...')
-                print(colors.warning('Open Pavucontrol and Select the Mkchromecast Sink.'))
+                print(colors.warning('Open Pavucontrol and Select the '
+                      'Mkchromecast Sink.'))
                 create_sink()
             print(colors.important('Starting Local Streaming Server'))
             print(colors.success('[Done]'))
@@ -71,14 +74,15 @@ class mk(object):
             self.cc.play_cast()
             self.show_control(self.control)
 
-        elif self.youtubeurl == None and self.source_url != None:
+        elif self.youtubeurl is None and self.source_url is not None:
             self.start_backend(self.encoder_backend)
             self.cc.initialize_cast()
             self.get_cc(self.select_cc)
             self.cc.play_cast()
             self.show_control(self.control)
 
-        elif youtubeurl != None and self.videoarg == False: # When casting youtube url, we do it through the audio module
+        # When casting youtube url, we do it through the audio module
+        elif youtubeurl is not None and self.videoarg is False:
             import mkchromecast.audio
             mkchromecast.audio.main()
             self.cc.initialize_cast()
@@ -88,7 +92,7 @@ class mk(object):
 
     def audio_macOS(self):
         """This method manages all related to casting audio in macOS"""
-        if self.youtubeurl == None and self.source_url == None:
+        if self.youtubeurl is None and self.source_url is None:
             self.start_backend(self.encoder_backend)
             self.cc.initialize_cast()
             self.get_cc(self.select_cc)
@@ -100,7 +104,7 @@ class mk(object):
             self.cc.play_cast()
             self.show_control(self.control)
 
-        elif self.youtubeurl == None and self.source_url != None:
+        elif self.youtubeurl is None and self.source_url is not None:
             self.start_backend(self.encoder_backend)
             self.cc.initialize_cast()
             self.get_cc(self.select_cc)
@@ -114,7 +118,8 @@ class mk(object):
             self.cc.play_cast()
             self.show_control(self.control)
 
-        elif self.youtubeurl != None and self.videoarg == False: # When casting youtube url, we do it through the audio module
+        # When casting youtube url, we do it through the audio module
+        elif self.youtubeurl is not None and self.videoarg is False:
             import mkchromecast.audio
             mkchromecast.audio.main()
             self.cc.initialize_cast()
@@ -136,7 +141,8 @@ class mk(object):
         """Get chromecast name, and let user select one from a list if
         select_cc flag is True.
         """
-        if select_cc == True: # This is done for the case that -s is passed
+        # This is done for the case that -s is passed
+        if select_cc is True:
             self.cc.sel_cc()
             self.cc.inp_cc()
             self.cc.get_cc()
@@ -145,29 +151,30 @@ class mk(object):
 
     def start_backend(self, encoder_backend):
         """Starting backends"""
-        if encoder_backend == 'node' and self.source_url == None:
+        if encoder_backend == 'node' and self.source_url is None:
             from mkchromecast.node import stream
             stream()
-        elif encoder_backend in self.backends and self.source_url == None:
+        elif encoder_backend in self.backends and self.source_url is None:
             import mkchromecast.audio
             mkchromecast.audio.main()
 
     def check_connection(self):
         """Check if the computer is connected to a network"""
         if self.cc.ip == '127.0.0.1':        # We verify the local IP.
-            print(colors.error('Your Computer is not Connected to Any Network'))
+            print(colors.error('Your Computer is not Connected to Any '
+                  'Network'))
             terminate()
-        elif self.cc.ip != '127.0.0.1' and self.discover == True:
+        elif self.cc.ip != '127.0.0.1' and self.discover is True:
             self.cc.initialize_cast()
             terminate()
 
     def terminate_app(self):
         """Terminate the app (kill app)"""
         self.cc.stop_cast()
-        if platform == 'Darwin':
+        if self.platform == 'Darwin':
             inputint()
             outputint()
-        elif platform == 'Linux' and adevice == None:
+        elif self.platform == 'Linux' and self.adevice is None:
             remove_sink()
         terminate()
 
@@ -179,7 +186,7 @@ class mk(object):
         print('')
         print(colors.options(           'Volume Up:')+' u')
         print(colors.options(         'Volume Down:')+' d')
-        if videoarg == True:
+        if self.videoarg is True:
             print(colors.options(       'Pause Casting:')+' p')
             print(colors.options(      'Resume Casting:')+' r')
         print(colors.options('Quit the Application:')+' q or Ctrl-C')
@@ -187,7 +194,7 @@ class mk(object):
 
     def show_control(self, control):
         """Method to show controls"""
-        if control == True:
+        if self.control is True:
             from mkchromecast.getch import getch, pause
 
             self.controls_msg()
@@ -197,30 +204,30 @@ class mk(object):
                     if(key == 'u'):
                         self.cc.volume_up()
                         if self.encoder_backend == 'ffmpeg':
-                            if self.debug == True:
+                            if self.debug is True:
                                 self.controls_msg()
                     elif(key == 'd'):
                         self.cc.volume_down()
                         if self.encoder_backend == 'ffmpeg':
-                            if self.debug == True:
+                            if self.debug is True:
                                 self.controls_msg()
                     elif(key == 'p'):
-                        if self.videoarg == True:
+                        if self.videoarg is True:
                             print('Pausing Casting Process...')
                             action = 'pause'
                             self.backend_handler(action, self.encoder_backend)
                             if self.encoder_backend == 'ffmpeg':
-                                if self.debug == True:
+                                if self.debug is True:
                                     self.controls_msg()
                         else:
                             pass
                     elif(key == 'r'):
-                        if self.videoarg == True:
+                        if self.videoarg is True:
                             print('Resuming Casting Process...')
                             action = 'resume'
                             self.backend_handler(action, self.encoder_backend)
                             if self.encoder_backend == 'ffmpeg':
-                                if self.debug == True:
+                                if self.debug is True:
                                     self.controls_msg()
                         else:
                             pass
@@ -234,15 +241,17 @@ class mk(object):
                 self.terminate_app()
 
         else:
-            if self.platform == 'Linux' and self.adevice == None:
-                print(colors.warning('Remember to open pavucontrol and select the mkchromecast sink.'))
+            if self.platform == 'Linux' and self.adevice is None:
+                print(colors.warning('Remember to open pavucontrol and select '
+                      'the mkchromecast sink.'))
             print('')
             print(colors.error('Ctrl-C to kill the Application at any Time'))
             print('')
-            try:
-                input()
-            except KeyboardInterrupt:
-                atexit.register(self.terminate_app())
+            signal.signal(signal.SIGINT,
+                          lambda *_: atexit.register(self.terminate_app()))
+            signal.signal(signal.SIGTERM,
+                          lambda *_: atexit.register(self.terminate_app()))
+            signal.pause()
 
     def backend_handler(self, action, backend):
         """Methods to handle pause and resume state of backends"""
@@ -250,20 +259,24 @@ class mk(object):
             subprocess.call(['pkill', '-STOP', '-f', 'ffmpeg'])
         elif action == 'resume' and backend == 'ffmpeg':
             subprocess.call(['pkill', '-CONT', '-f', 'ffmpeg'])
-        elif action == 'pause' and backend == 'node' and self.platform == 'Linux':
+        elif (action == 'pause' and backend == 'node' and
+              self.platform == 'Linux'):
             subprocess.call(['pkill', '-STOP', '-f', 'nodejs'])
-        elif action == 'resume' and backend == 'node' and self.platform == 'Linux':
+        elif (action == 'resume' and backend == 'node' and
+              self.platform == 'Linux'):
             subprocess.call(['pkill', '-CONT', '-f', 'nodejs'])
-        elif action == 'pause' and backend == 'node' and self.platform == 'Darwin':
+        elif (action == 'pause' and backend == 'node' and
+              self.platform == 'Darwin'):
             subprocess.call(['pkill', '-STOP', '-f', 'node'])
-        elif action == 'resume' and backend == 'node' and self.platform == 'Darwin':
+        elif (action == 'resume' and backend == 'node' and
+              self.platform == 'Darwin'):
             subprocess.call(['pkill', '-CONT', '-f', 'node'])
 
     def start_tray(self):
         """This method starts the system tray"""
         import mkchromecast.systray
-        checkmktmp()
-        writePidFile()
+        mkchromecast.__init__.checkmktmp()
+        mkchromecast.__init__.writePidFile()
         mkchromecast.systray.main()
 
 if __name__ == "__main__":
